==> fheroes2_1.0.12+dfsg.orig.tar.gz: fheroes2-1.0.12+dfsg/src/fheroes2/castle/castle_building_info.h <==
/***************************************************************************
 *   fheroes2: https://github.com/ihhub/fheroes2                           *
 *   Copyright (C) 2021 - 2022                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#pragma once

#include <vector>

#include "castle.h"
#include "math_base.h"

enum class GameVersion : int;

namespace fheroes2
{
    Rect getCastleBuildingArea( const int race, const building_t buildingId );

    const char * getBuildingName( const int race, const building_t buildingId );

    const char * getBuildingDescription( const int race, const building_t buildingId );

    std::vector<building_t> getBuildingDrawingPriorities( const int race, const GameVersion version );
}

==> fheroes2-1.1.1.tar.gz: fheroes2-1.1.1/src/fheroes2/castle/castle_building_info.h <==
/***************************************************************************
 *   fheroes2: https://github.com/ihhub/fheroes2                           *
 *   Copyright (C) 2021 - 2024                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#pragma once

#include <string>
#include <vector>

#include "castle.h"
#include "math_base.h"

enum class GameVersion : int;

namespace fheroes2
{
    Rect getCastleBuildingArea( const int race, const building_t buildingId );

    const char * getBuildingName( const int race, const building_t buildingId );

    const char * getBuildingDescription( const int race, const building_t buildingId );

    // Returns the upgraded building ID for the given one or the input building if no upgrade is available.
    building_t getUpgradeForBuilding( const int race, const building_t buildingId );

    building_t getBuildingRequirement( const int race, const building_t building );

    std::string getBuildingRequirementString( const int race, const building_t building );

    int getIndexBuildingSprite( const building_t build );

    std::vector<building_t> getBuildingDrawingPriorities( const int race, const GameVersion version );
}
